#! /usr/bin/env python
# -*- coding: utf-8 -*-
import solid
from types import SimpleNamespace

class SPNamespace(SimpleNamespace):
    def include_scad(self, scad_path):
        solid.use(scad_path, dest_namespace_dict=self.__dict__)

def import_all_scad():
    import os
    mcad_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), 'MCAD'))
    # TODO: This doesn't include any subdirectories
    for f in os.listdir(mcad_dir):
        if not f.lower().endswith('.scad'):
            continue
        name, ext = os.path.splitext(f)
        scad_path = os.path.join(mcad_dir, f)
        n = SPNamespace()
        try:
            n.include_scad(scad_path)
            globals()[name] = n
        except Exception as e:
            print(f'Unable to load SCAD code at {scad_path} with error: {e}')
    return True

# NOTE: simply importing solid_mcad does a lot of work; reading & parsing 20+ files,
# then creating Python classes for each module in a scad file. It's expensive,
# but this way you can treat SCAD code as if it were all python with, e.g. 
# from solid_mcad import involute_gears
# gears = involute_gears.test_bevel_gear_pair()
import_all_scad()